@@ -17,11 +17,11 @@ Dancer::Plugin::Interchange6 - Interchange6 Shop Plugin for Dancer
 
 =head1 VERSION
 
-Version 0.040
+Version 0.051
 
 =cut
 
-our $VERSION = '0.040';
+our $VERSION = '0.051';
 
 =head1 REQUIREMENTS
 
@@ -73,6 +73,34 @@ of your main module:
 Please refer to L<Dancer::Plugin::Interchange6::Routes> for configuration options
 and further information.
 
+=head1 KEYWORDS
+
+=head2 shop_cart
+
+Returns L<Dancer::Plugin::Interchange6::Cart> object.
+
+=head2 shop_charge
+
+Creates payment order and authorizes amount.
+
+=head2 shop_schema
+
+Returns L<Interchange6::Schema> object.
+
+=head2 shop_...
+
+Accessors for L<Interchange6::Schema> result classes. You can use it
+to retrieve a single object or the corresponding result set.
+
+    shop_product('F0001')->uri;
+
+    shop_navigation->search({type => 'manufacturer',
+                             active => 1});
+
+Available accessors are C<shop_address>, C<shop_attribute>, C<shop_country>,
+C<shop_message>, C<shop_navigation>, C<shop_order>, C<shop_product>,
+C<shop_state> and C<shop_user>.
+
 =head1 HOOKS
 
 This plugin installs the following hooks:
@@ -225,6 +253,10 @@ register shop_country => sub {
     _shop_resultset('Country', @_);
 };
 
+register shop_message => sub {
+    _shop_resultset('Message', @_);
+};
+
 register shop_navigation => sub {
     _shop_resultset('Navigation', @_);
 };
@@ -237,8 +269,8 @@ register shop_product => sub {
     _shop_resultset('Product', @_);
 };
 
-register shop_review => sub {
-    _shop_resultset('Review', @_);
+register shop_state => sub {
+    _shop_resultset('State', @_);
 };
 
 register shop_user => sub {
